ComplexCPCCARotator
===================

.. currentmodule:: xeofs.cross

.. autoclass:: ComplexCPCCARotator
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ComplexCPCCARotator.__init__
      ~ComplexCPCCARotator.components
      ~ComplexCPCCARotator.components_amplitude
      ~ComplexCPCCARotator.components_phase
      ~ComplexCPCCARotator.compute
      ~ComplexCPCCARotator.correlation_coefficients_X
      ~ComplexCPCCARotator.correlation_coefficients_Y
      ~ComplexCPCCARotator.cross_correlation_coefficients
      ~ComplexCPCCARotator.deserialize
      ~ComplexCPCCARotator.fit
      ~ComplexCPCCARotator.fraction_variance_X_explained_by_X
      ~ComplexCPCCARotator.fraction_variance_Y_explained_by_X
      ~ComplexCPCCARotator.fraction_variance_Y_explained_by_Y
      ~ComplexCPCCARotator.get_params
      ~ComplexCPCCARotator.get_serialization_attrs
      ~ComplexCPCCARotator.heterogeneous_patterns
      ~ComplexCPCCARotator.homogeneous_patterns
      ~ComplexCPCCARotator.inverse_transform
      ~ComplexCPCCARotator.load
      ~ComplexCPCCARotator.predict
      ~ComplexCPCCARotator.save
      ~ComplexCPCCARotator.scores
      ~ComplexCPCCARotator.scores_amplitude
      ~ComplexCPCCARotator.scores_phase
      ~ComplexCPCCARotator.serialize
      ~ComplexCPCCARotator.squared_covariance_fraction
      ~ComplexCPCCARotator.transform
   
   

   
   
   